# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from datetime import datetime

from ..._models import BaseModel

__all__ = ["TranscriptionRetrieveResponse", "Data", "DataPayload", "DataTimestamp"]


class DataPayload(BaseModel):
    transcription: Optional[str] = None
    """Transcription of the audio"""


class DataTimestamp(BaseModel):
    complete: Optional[int] = None
    """Complete timestamp"""

    start: Optional[int] = None
    """Start timestamp"""


class Data(BaseModel):
    id: Optional[str] = None
    """Unique identifier for the audio transcription"""

    payload: Optional[DataPayload] = None
    """Either markdown or JSON representation of the note.

    Both can be present as well.
    """

    timestamp: Optional[DataTimestamp] = None


class TranscriptionRetrieveResponse(BaseModel):
    data: Optional[Data] = None

    date: Optional[datetime] = None
    """Timestamp of the response"""

    status: Optional[str] = None
    """Status of the response"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List, Union, Optional
from datetime import date

import httpx

from ..types import note_create_params
from .._types import NOT_GIVEN, Body, Query, Headers, NotGiven
from .._utils import maybe_transform, async_maybe_transform
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.delete_response import DeleteResponse
from ..types.note_create_response import NoteCreateResponse
from ..types.note_retrieve_response import NoteRetrieveResponse

__all__ = ["NotesResource", "AsyncNotesResource"]


class NotesResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> NotesResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/sullyai/sullyai-python#accessing-raw-response-data-eg-headers
        """
        return NotesResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> NotesResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/sullyai/sullyai-python#with_streaming_response
        """
        return NotesResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        date: Union[str, date],
        transcript: str,
        context: Optional[str] | NotGiven = NOT_GIVEN,
        instructions: Optional[List[str]] | NotGiven = NOT_GIVEN,
        medication_list: str | NotGiven = NOT_GIVEN,
        note_type: note_create_params.NoteType | NotGiven = NOT_GIVEN,
        patient_info: note_create_params.PatientInfo | NotGiven = NOT_GIVEN,
        previous_note: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> NoteCreateResponse:
        """
        Creates a new note

        Args:
          date: Date of the patient encounter

          context: Additional context for note generation. This field is optional.

          instructions: Special instructions for note generation. This field is optional.

          medication_list: List of up to 50 medications (comma separated) to use as reference for fixing
              spelling errors. This field is optional.

          patient_info: Optional patient information

          previous_note: Reference to a previous note if this is a follow-up. This field is optional.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/v1/notes",
            body=maybe_transform(
                {
                    "date": date,
                    "transcript": transcript,
                    "context": context,
                    "instructions": instructions,
                    "medication_list": medication_list,
                    "note_type": note_type,
                    "patient_info": patient_info,
                    "previous_note": previous_note,
                },
                note_create_params.NoteCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoteCreateResponse,
        )

    def retrieve(
        self,
        note_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> NoteRetrieveResponse:
        """
        Gets a single note based on the ID supplied

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not note_id:
            raise ValueError(f"Expected a non-empty value for `note_id` but received {note_id!r}")
        return self._get(
            f"/v1/notes/{note_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoteRetrieveResponse,
        )

    def delete(
        self,
        note_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> DeleteResponse:
        """
        Deletes a single note based on the ID supplied

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not note_id:
            raise ValueError(f"Expected a non-empty value for `note_id` but received {note_id!r}")
        return self._delete(
            f"/v1/notes/{note_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=DeleteResponse,
        )


class AsyncNotesResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncNotesResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/sullyai/sullyai-python#accessing-raw-response-data-eg-headers
        """
        return AsyncNotesResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncNotesResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/sullyai/sullyai-python#with_streaming_response
        """
        return AsyncNotesResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        date: Union[str, date],
        transcript: str,
        context: Optional[str] | NotGiven = NOT_GIVEN,
        instructions: Optional[List[str]] | NotGiven = NOT_GIVEN,
        medication_list: str | NotGiven = NOT_GIVEN,
        note_type: note_create_params.NoteType | NotGiven = NOT_GIVEN,
        patient_info: note_create_params.PatientInfo | NotGiven = NOT_GIVEN,
        previous_note: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> NoteCreateResponse:
        """
        Creates a new note

        Args:
          date: Date of the patient encounter

          context: Additional context for note generation. This field is optional.

          instructions: Special instructions for note generation. This field is optional.

          medication_list: List of up to 50 medications (comma separated) to use as reference for fixing
              spelling errors. This field is optional.

          patient_info: Optional patient information

          previous_note: Reference to a previous note if this is a follow-up. This field is optional.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/v1/notes",
            body=await async_maybe_transform(
                {
                    "date": date,
                    "transcript": transcript,
                    "context": context,
                    "instructions": instructions,
                    "medication_list": medication_list,
                    "note_type": note_type,
                    "patient_info": patient_info,
                    "previous_note": previous_note,
                },
                note_create_params.NoteCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoteCreateResponse,
        )

    async def retrieve(
        self,
        note_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> NoteRetrieveResponse:
        """
        Gets a single note based on the ID supplied

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not note_id:
            raise ValueError(f"Expected a non-empty value for `note_id` but received {note_id!r}")
        return await self._get(
            f"/v1/notes/{note_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoteRetrieveResponse,
        )

    async def delete(
        self,
        note_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> DeleteResponse:
        """
        Deletes a single note based on the ID supplied

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not note_id:
            raise ValueError(f"Expected a non-empty value for `note_id` but received {note_id!r}")
        return await self._delete(
            f"/v1/notes/{note_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=DeleteResponse,
        )


class NotesResourceWithRawResponse:
    def __init__(self, notes: NotesResource) -> None:
        self._notes = notes

        self.create = to_raw_response_wrapper(
            notes.create,
        )
        self.retrieve = to_raw_response_wrapper(
            notes.retrieve,
        )
        self.delete = to_raw_response_wrapper(
            notes.delete,
        )


class AsyncNotesResourceWithRawResponse:
    def __init__(self, notes: AsyncNotesResource) -> None:
        self._notes = notes

        self.create = async_to_raw_response_wrapper(
            notes.create,
        )
        self.retrieve = async_to_raw_response_wrapper(
            notes.retrieve,
        )
        self.delete = async_to_raw_response_wrapper(
            notes.delete,
        )


class NotesResourceWithStreamingResponse:
    def __init__(self, notes: NotesResource) -> None:
        self._notes = notes

        self.create = to_streamed_response_wrapper(
            notes.create,
        )
        self.retrieve = to_streamed_response_wrapper(
            notes.retrieve,
        )
        self.delete = to_streamed_response_wrapper(
            notes.delete,
        )


class AsyncNotesResourceWithStreamingResponse:
    def __init__(self, notes: AsyncNotesResource) -> None:
        self._notes = notes

        self.create = async_to_streamed_response_wrapper(
            notes.create,
        )
        self.retrieve = async_to_streamed_response_wrapper(
            notes.retrieve,
        )
        self.delete = async_to_streamed_response_wrapper(
            notes.delete,
        )



from pathlib import Path

import anyio
import pytest
from dirty_equals import IsDict, IsList, IsBytes, IsTuple

from sullyai._files import to_httpx_files, async_to_httpx_files

readme_path = Path(__file__).parent.parent.joinpath("README.md")


def test_pathlib_includes_file_name() -> None:
    result = to_httpx_files({"file": readme_path})
    print(result)
    assert result == IsDict({"file": IsTuple("README.md", IsBytes())})


def test_tuple_input() -> None:
    result = to_httpx_files([("file", readme_path)])
    print(result)
    assert result == IsList(IsTuple("file", IsTuple("README.md", IsBytes())))


@pytest.mark.asyncio
async def test_async_pathlib_includes_file_name() -> None:
    result = await async_to_httpx_files({"file": readme_path})
    print(result)
    assert result == IsDict({"file": IsTuple("README.md", IsBytes())})


@pytest.mark.asyncio
async def test_async_supports_anyio_path() -> None:
    result = await async_to_httpx_files({"file": anyio.Path(readme_path)})
    print(result)
    assert result == IsDict({"file": IsTuple("README.md", IsBytes())})


@pytest.mark.asyncio
async def test_async_tuple_input() -> None:
    result = await async_to_httpx_files([("file", readme_path)])
    print(result)
    assert result == IsList(IsTuple("file", IsTuple("README.md", IsBytes())))


def test_string_not_allowed() -> None:
    with pytest.raises(TypeError, match="Expected file types input to be a FileContent type or to be a tuple"):
        to_httpx_files(
            {
                "file": "foo",  # type: ignore
            }
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .audio import (
    AudioResource,
    AsyncAudioResource,
    AudioResourceWithRawResponse,
    AsyncAudioResourceWithRawResponse,
    AudioResourceWithStreamingResponse,
    AsyncAudioResourceWithStreamingResponse,
)
from .transcriptions import (
    TranscriptionsResource,
    AsyncTranscriptionsResource,
    TranscriptionsResourceWithRawResponse,
    AsyncTranscriptionsResourceWithRawResponse,
    TranscriptionsResourceWithStreamingResponse,
    AsyncTranscriptionsResourceWithStreamingResponse,
)

__all__ = [
    "TranscriptionsResource",
    "AsyncTranscriptionsResource",
    "TranscriptionsResourceWithRawResponse",
    "AsyncTranscriptionsResourceWithRawResponse",
    "TranscriptionsResourceWithStreamingResponse",
    "AsyncTranscriptionsResourceWithStreamingResponse",
    "AudioResource",
    "AsyncAudioResource",
    "AudioResourceWithRawResponse",
    "AsyncAudioResourceWithRawResponse",
    "AudioResourceWithStreamingResponse",
    "AsyncAudioResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, TypedDict

from ..._types import FileTypes

__all__ = ["TranscriptionCreateParams"]


class TranscriptionCreateParams(TypedDict, total=False):
    audio: Required[FileTypes]
    """Audio file to transcribe (supported formats: wav, mp3, m4a, ogg)"""

    language: str
    """Language code for transcription:

    - English (en-US, en-GB) - Spanish (es) - French (fr) - German (de) - Italian
      (it) - Portuguese (pt) - Dutch (nl) - Japanese (ja) - Korean (ko) - Chinese
      (zh) - Russian (ru)
    """



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .stream import (
    StreamResource,
    AsyncStreamResource,
    StreamResourceWithRawResponse,
    AsyncStreamResourceWithRawResponse,
    StreamResourceWithStreamingResponse,
    AsyncStreamResourceWithStreamingResponse,
)
from .transcriptions import (
    TranscriptionsResource,
    AsyncTranscriptionsResource,
    TranscriptionsResourceWithRawResponse,
    AsyncTranscriptionsResourceWithRawResponse,
    TranscriptionsResourceWithStreamingResponse,
    AsyncTranscriptionsResourceWithStreamingResponse,
)

__all__ = [
    "StreamResource",
    "AsyncStreamResource",
    "StreamResourceWithRawResponse",
    "AsyncStreamResourceWithRawResponse",
    "StreamResourceWithStreamingResponse",
    "AsyncStreamResourceWithStreamingResponse",
    "TranscriptionsResource",
    "AsyncTranscriptionsResource",
    "TranscriptionsResourceWithRawResponse",
    "AsyncTranscriptionsResourceWithRawResponse",
    "TranscriptionsResourceWithStreamingResponse",
    "AsyncTranscriptionsResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .transcription_create_params import TranscriptionCreateParams as TranscriptionCreateParams
from .transcription_create_response import TranscriptionCreateResponse as TranscriptionCreateResponse
from .transcription_retrieve_response import TranscriptionRetrieveResponse as TranscriptionRetrieveResponse



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List

import httpx

from ..types import note_style_create_params
from .._types import NOT_GIVEN, Body, Query, Headers, NotGiven
from .._utils import maybe_transform, async_maybe_transform
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.note_style_create_response import NoteStyleCreateResponse

__all__ = ["NoteStylesResource", "AsyncNoteStylesResource"]


class NoteStylesResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> NoteStylesResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/sullyai/sullyai-python#accessing-raw-response-data-eg-headers
        """
        return NoteStylesResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> NoteStylesResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/sullyai/sullyai-python#with_streaming_response
        """
        return NoteStylesResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        sample_note: str,
        instructions: List[str] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> NoteStyleCreateResponse:
        """
        Creates a note style

        Args:
          sample_note: Sample note text to base the style on

          instructions: Optional instructions for note generation

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/v1/note-styles",
            body=maybe_transform(
                {
                    "sample_note": sample_note,
                    "instructions": instructions,
                },
                note_style_create_params.NoteStyleCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoteStyleCreateResponse,
        )


class AsyncNoteStylesResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncNoteStylesResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/sullyai/sullyai-python#accessing-raw-response-data-eg-headers
        """
        return AsyncNoteStylesResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncNoteStylesResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/sullyai/sullyai-python#with_streaming_response
        """
        return AsyncNoteStylesResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        sample_note: str,
        instructions: List[str] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> NoteStyleCreateResponse:
        """
        Creates a note style

        Args:
          sample_note: Sample note text to base the style on

          instructions: Optional instructions for note generation

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/v1/note-styles",
            body=await async_maybe_transform(
                {
                    "sample_note": sample_note,
                    "instructions": instructions,
                },
                note_style_create_params.NoteStyleCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoteStyleCreateResponse,
        )


class NoteStylesResourceWithRawResponse:
    def __init__(self, note_styles: NoteStylesResource) -> None:
        self._note_styles = note_styles

        self.create = to_raw_response_wrapper(
            note_styles.create,
        )


class AsyncNoteStylesResourceWithRawResponse:
    def __init__(self, note_styles: AsyncNoteStylesResource) -> None:
        self._note_styles = note_styles

        self.create = async_to_raw_response_wrapper(
            note_styles.create,
        )


class NoteStylesResourceWithStreamingResponse:
    def __init__(self, note_styles: NoteStylesResource) -> None:
        self._note_styles = note_styles

        self.create = to_streamed_response_wrapper(
            note_styles.create,
        )


class AsyncNoteStylesResourceWithStreamingResponse:
    def __init__(self, note_styles: AsyncNoteStylesResource) -> None:
        self._note_styles = note_styles

        self.create = async_to_streamed_response_wrapper(
            note_styles.create,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import datetime
from typing import List, Union, Optional
from typing_extensions import Literal, Required, Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["NoteCreateParams", "NoteType", "PatientInfo"]


class NoteCreateParams(TypedDict, total=False):
    date: Required[Annotated[Union[str, datetime.date], PropertyInfo(format="iso8601")]]
    """Date of the patient encounter"""

    transcript: Required[str]

    context: Optional[str]
    """Additional context for note generation. This field is optional."""

    instructions: Optional[List[str]]
    """Special instructions for note generation. This field is optional."""

    medication_list: Annotated[str, PropertyInfo(alias="medicationList")]
    """
    List of up to 50 medications (comma separated) to use as reference for fixing
    spelling errors. This field is optional.
    """

    note_type: Annotated[NoteType, PropertyInfo(alias="noteType")]

    patient_info: Annotated[PatientInfo, PropertyInfo(alias="patientInfo")]
    """Optional patient information"""

    previous_note: Annotated[str, PropertyInfo(alias="previousNote")]
    """Reference to a previous note if this is a follow-up. This field is optional."""


class NoteType(TypedDict, total=False):
    description: str
    """A brief overview of the note."""

    include_json: Annotated[bool, PropertyInfo(alias="includeJson")]
    """Determines whether to include a JSON payload in the custom note output.

    This option is applicable only for custom notes and defaults to `false`.
    Enabling this will increase latency and payload size.
    """

    template: Union[str, object]
    """Custom template to generate the note.

    This is applicable only when `type` is set to `note_style` or `note_template`.

    - When `type` is `note_style`, this is a note style string
    - When `type` is `note_template`, this is a
      [Note Template](/api-reference/schemas/note-template) payload
    """

    type: Literal["soap", "note_style", "note_template"]
    """Determines the type of note to generate.

    - Use `note_style` to provide a note style string
    - Use `note_template` to provide a
      [Note Template](/api-reference/schemas/note-template) payload
    - Use `soap` for the default SOAP template
    """


class PatientInfo(TypedDict, total=False):
    date_of_birth: Annotated[Union[str, datetime.date], PropertyInfo(alias="dateOfBirth", format="iso8601")]

    gender: Literal["male", "female", "other", "prefer not to say", "unspecified"]

    name: str



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from datetime import datetime

from .._models import BaseModel

__all__ = ["NoteStyleCreateResponse", "Data"]


class Data(BaseModel):
    template: Optional[str] = None
    """The created note style"""


class NoteStyleCreateResponse(BaseModel):
    data: Optional[Data] = None

    date: Optional[datetime] = None
    """Timestamp of the response"""

    status: Optional[str] = None
    """Status of the response"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .shared import Section as Section, HeadingSection as HeadingSection
from .delete_response import DeleteResponse as DeleteResponse
from .note_create_params import NoteCreateParams as NoteCreateParams
from .note_create_response import NoteCreateResponse as NoteCreateResponse
from .note_retrieve_response import NoteRetrieveResponse as NoteRetrieveResponse
from .note_style_create_params import NoteStyleCreateParams as NoteStyleCreateParams
from .note_style_create_response import NoteStyleCreateResponse as NoteStyleCreateResponse



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List
from typing_extensions import Required, Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["NoteStyleCreateParams"]


class NoteStyleCreateParams(TypedDict, total=False):
    sample_note: Required[Annotated[str, PropertyInfo(alias="sampleNote")]]
    """Sample note text to base the style on"""

    instructions: List[str]
    """Optional instructions for note generation"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ...._types import NOT_GIVEN, Body, Query, Headers, NotGiven
from ...._utils import maybe_transform, async_maybe_transform
from ...._compat import cached_property
from ...._resource import SyncAPIResource, AsyncAPIResource
from ...._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ...._base_client import make_request_options
from ....types.audio.transcriptions import stream_create_token_params
from ....types.audio.transcriptions.stream_create_token_response import StreamCreateTokenResponse

__all__ = ["StreamResource", "AsyncStreamResource"]


class StreamResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> StreamResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/sullyai/sullyai-python#accessing-raw-response-data-eg-headers
        """
        return StreamResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> StreamResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/sullyai/sullyai-python#with_streaming_response
        """
        return StreamResourceWithStreamingResponse(self)

    def create_token(
        self,
        *,
        expires_in: int,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> StreamCreateTokenResponse:
        """
        Create a temporary authentication token for Streaming Speech-to-Text

        Args:
          expires_in: Duration of the token in seconds

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/v1/audio/transcriptions/stream/token",
            body=maybe_transform({"expires_in": expires_in}, stream_create_token_params.StreamCreateTokenParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=StreamCreateTokenResponse,
        )


class AsyncStreamResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncStreamResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/sullyai/sullyai-python#accessing-raw-response-data-eg-headers
        """
        return AsyncStreamResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncStreamResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/sullyai/sullyai-python#with_streaming_response
        """
        return AsyncStreamResourceWithStreamingResponse(self)

    async def create_token(
        self,
        *,
        expires_in: int,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> StreamCreateTokenResponse:
        """
        Create a temporary authentication token for Streaming Speech-to-Text

        Args:
          expires_in: Duration of the token in seconds

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/v1/audio/transcriptions/stream/token",
            body=await async_maybe_transform(
                {"expires_in": expires_in}, stream_create_token_params.StreamCreateTokenParams
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=StreamCreateTokenResponse,
        )


class StreamResourceWithRawResponse:
    def __init__(self, stream: StreamResource) -> None:
        self._stream = stream

        self.create_token = to_raw_response_wrapper(
            stream.create_token,
        )


class AsyncStreamResourceWithRawResponse:
    def __init__(self, stream: AsyncStreamResource) -> None:
        self._stream = stream

        self.create_token = async_to_raw_response_wrapper(
            stream.create_token,
        )


class StreamResourceWithStreamingResponse:
    def __init__(self, stream: StreamResource) -> None:
        self._stream = stream

        self.create_token = to_streamed_response_wrapper(
            stream.create_token,
        )


class AsyncStreamResourceWithStreamingResponse:
    def __init__(self, stream: AsyncStreamResource) -> None:
        self._stream = stream

        self.create_token = async_to_streamed_response_wrapper(
            stream.create_token,
        )
